==> ytx-wechat-crm-1.0.4.tgz: package/src/lib/subscribe.js <==
'use strict';
import redisUtil from '../utils/redis.js';
const redis = redisUtil.getCli();
class Subscribe{
	constructor(wechatapi,config){
		this.wechatapi = wechatapi;
		this.broadcastImgKey= "crm:broadcast:img";
		this.config = config;
	}
	subscribe(message){
		let openid = message.to.id;
		console.log(message);
		return new Promise((resolve,reject)=>{
			if(message.type == 'TEXT'){
				this.sendTEXT(openid, message).then((status)=>{
					resolve()
				}).catch((err)=>{
					reject(err);
				});
			}else if(message.type == 'IMAGE'){
				this.sendIMAGE(openid, message).then((status)=>{
	             	resolve()
	            }).catch((err)=>{
	             	reject(err);
	            });
			}else if(message.type == 'AUDIO'){
				this.sendAUDIO(openid, message).then((status)=>{
	             	resolve()
	            }).catch((err)=>{
	             	reject(err);
	            });
			}else if(message.type == 'EXTENSION'){
				this.sendEXTENSION(openid, message).then((status)=>{
	             	resolve()
	            }).catch((err)=>{
	             	reject(err);
	            });
			}else{
				reject("invlid msg type");
			}
		})
	}

	sendTEXT(openid, message) {
		return new Promise((resolve,reject)=>{
			this.wechatapi.sendText(openid, message.content,(err,result)=>{
				if(err){
					reject(err);
				}else{
					resolve(result);
				}
			});
		})
	};

	sendIMAGE(openid, message){
		return new Promise((resolve,reject)=>{
			let broadcastRecordId = message.ext.broadcastRecordId;
			let fileName = message.attachmentId + "." + message.format;
			let url = this.config.crmfiles + fileName;
			if (broadcastRecordId) {
				redis.sismember(this.broadcastImgKey,broadcastRecordId,(err,media_id)=>{
					if(media_id){
						return this.wechatapi.sendIMAGE(openid,media_id);
					}else{
						return this.downloadAndSendImg(openId,url,broadcastRecordId);
					}
				})
			}else{
				return this.downloadAndSendImg(openid,url,broadcastRecordId);
			}
		})
	}

	sendEXTENSION(openid, message) {
		return new Promise((resolve,reject)=>{
			let ext =message.ext;
			if (ext && ext.type === 'ACTIVITY') {
		      	article = {
			        title: ext.title,
			        picurl: ext.img,
			        description: ext.description,
			        url: ext.url
		      	};
		      	wechatApi.sendNews(openid,[article],(err,result)=>{
					if(err){
						reject(err);
					}else{
						resolve(result);
					}
				});
		    }
	      	if (ext && ext.type === 'ENDING') {
		      	wechatApi.sendText(openid, message.content,(err,result)=>{
					if(err){
						reject(err);
					}else{
						resolve(result);
					}
				});
		    }
		})
	};

	sendAUDIO(openid, message){
		return new Promise((resolve,reject)=>{
			//todo
			resolve()
		})
	}
	downloadAndSendImg(openid, url,  broadcastRecordId) {
		return new Promise((resolve,reject)=>{
			download(url).then((file)=>{
				console.log(file)
				this.wechatapi.uploadImage(file,(err,data)=>{
					if(err){
						reject(err);
					}else{
						if(broadcastRecordId){
							redis.sdd(this.broadcastImgKey,broadcastRecordId);
						}
						this.wechatapi.sendImage(openid, data.media_id,(err,data)=>{
							if(err){
								reject(err);
								console.log(err)
							}else{
								resolve(data);
								console.log(data);
							}
						});
					}
				})
			})
		})
	};
}

module.exports = Subscribe;

==> ytx-wechat-crm-1.1.1.tgz: package/src/lib/subscribe.js <==
'use strict';
import redisUtil from '../utils/redis.js';
import download from '../utils/download.js';

class Subscribe{
	constructor(wechatapi,config){
		this.wechatapi = wechatapi;
		this.broadcastImgKey= "crm:broadcast:img";
		this.config = config;
		this.redis = redisUtil.getCli(config);

	}
	subscribe(message){
		let openid = message.to.id;
		console.log(message);
		return new Promise((resolve,reject)=>{
			if(message.type == 'TEXT'){
				this.sendTEXT(openid, message).then((status)=>{
					resolve()
				}).catch((err)=>{
					reject(err);
				});
			}else if(message.type == 'IMAGE'){
				this.sendIMAGE(openid, message).then((status)=>{
	             	resolve()
	            }).catch((err)=>{
	             	reject(err);
	            });
			}else if(message.type == 'AUDIO'){
				this.sendAUDIO(openid, message).then((status)=>{
	             	resolve()
	            }).catch((err)=>{
	             	reject(err);
	            });
			}else if(message.type == 'EXTENSION'){
				this.sendEXTENSION(openid, message).then((status)=>{
	             	resolve()
	            }).catch((err)=>{
	             	reject(err);
	            });
			}else{
				reject("invlid msg type");
			}
		})
	}

	sendTEXT(openid, message) {
		return new Promise((resolve,reject)=>{
			this.wechatapi.sendText(openid, message.content,(err,result)=>{
				if(err){
					reject(err);
				}else{
					resolve(result);
				}
			});
		})
	};

	sendIMAGE(openid, message){
		return new Promise((resolve,reject)=>{
			let broadcastRecordId = message.ext.broadcastRecordId;
			let isBroadcast = message.ext.isBroadcast
			let url = message.attachmentUrl;
			if (isBroadcast) {
				this.redis.sismember(this.broadcastImgKey,broadcastRecordId,(err,media_id)=>{
					if(media_id){
						return this.wechatapi.sendIMAGE(openid,media_id);
					}else{
						return this.downloadAndSendImg(openid,message.ext.url,broadcastRecordId);
					}
				})
			}else{
				return this.downloadAndSendImg(openid,url,broadcastRecordId);
			}
		})
	}

	sendEXTENSION(openid, message) {
		return new Promise((resolve,reject)=>{
			let ext =message.ext;
			if (ext && ext.type === 'ACTIVITY') {
		      	article = {
			        title: ext.title,
			        picurl: ext.img,
			        description: ext.description,
			        url: ext.url
		      	};
		      	wechatApi.sendNews(openid,[article],(err,result)=>{
					if(err){
						reject(err);
					}else{
						resolve(result);
					}
				});
		    }
	      	if (ext && ext.type === 'ENDING') {
		      	wechatApi.sendText(openid, message.content,(err,result)=>{
					if(err){
						reject(err);
					}else{
						resolve(result);
					}
				});
		    }
		})
	};

	sendAUDIO(openid, message){
		return new Promise((resolve,reject)=>{
			//todo
			resolve()
		})
	}
	downloadAndSendImg(openid, url,  broadcastRecordId) {
		return new Promise((resolve,reject)=>{
			download(url).then((file)=>{
				console.log(file)
				this.wechatapi.uploadImage(file,(err,data)=>{
					if(err){
						reject(err);
					}else{
						if(broadcastRecordId){
							this.redis.sadd(this.broadcastImgKey,broadcastRecordId);
						}
						this.wechatapi.sendImage(openid, data.media_id,(err,data)=>{
							if(err){
								reject(err);
								console.log(err)
							}else{
								resolve(data);
								console.log(data);
							}
						});
					}
				})
			})
		})
	};
}

module.exports = Subscribe;
